#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-75spxkH6uPB8YRvPJHhU2s
key:                  xml-conduit-1.9.1.4-75spxkH6uPB8YRvPJHhU2s
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  c9d2f536d3efcfafca3960acf5cb4bd1
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-75spxkH6uPB8YRvPJHhU2s
depends:
    attoparsec-0.14.4-KXEn0UTGiviKHW1W4Txem1 base-4.18.2.1
    blaze-html-0.9.2.0-2DuDW300GIs3GBNnqFMort
    blaze-markup-0.8.3.0-5HaQctUz2WgK7Wu4GhbGjR bytestring-0.11.5.3
    conduit-1.3.6.1-ASxyqnNN5o6JNEZENxLkTo
    conduit-extra-1.3.8-4ND3rHkWnMCxT3MRqBhox containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    resourcet-1.2.6-1xyvvIMDXXY2PZlggmi6VN text-2.0.2
    transformers-0.6.1.0 xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

